﻿using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;

namespace GGJ_Game
{
    class Collectable
    {
        Texture2D texture;

        private SpriteSheet spriteSheed;
        private AnimationPlayer animationPlayer;
        public int xPos;
        public int yPos;
        public string typeName;

        public Vector2 TextureSize
        {
            get { return textureSize; }
            set { textureSize = value;
                    TextureWidth = (int)TextureSize.X;
                    TextureWidth = (int)TextureSize.Y;
            }
        }

        public int TextureWidth = 40;   // warning: inconsistent if using spritesheeds, in this case we must check the spreadsheet framesize
        public int TextureHeight = 32;
        private Vector2 textureSize = new Vector2(40, 32);
        private float scale = 1;

        public Collectable(int x, int y, ContentManager content, string texturePathName, Vector2 textureSize, float scale = 1, bool loadAsSpriteSheed = false)
        {
            this.xPos = x;
            this.yPos = y;
            this.typeName = texturePathName;
            this.TextureSize = textureSize;
            this.scale = scale;
            if (loadAsSpriteSheed)
            {
                spriteSheed = new SpriteSheet(content.Load<Texture2D>(texturePathName), 0.1f, true);
                animationPlayer = new AnimationPlayer();
                animationPlayer.PlayAnimation(spriteSheed);
            }
            else
            {
                // Load as normal 2d texture
                texture = content.Load<Texture2D>(texturePathName);
            }
        }

        public void Update(GameTime gameTime)
        {
            if (animationPlayer != null)
            {
                animationPlayer.Update(gameTime);
            }
        }

        public void Draw(GameTime gameTime, SpriteBatch spriteBatch, Vector2? strechedTileSize = null)
        {
            // Draw via animation player or by hand
             if (animationPlayer != null)
            {
                // Hack for animating the portal, everything else would properbly not work
                Vector2 drawPosition = new Vector2((xPos+1) * strechedTileSize.Value.X+1, (yPos +2) * strechedTileSize.Value.Y);
                drawPosition.X -= 5;
                animationPlayer.Draw(gameTime, spriteBatch, drawPosition, SpriteEffects.None);
                return;
            }
            else
            {
                Vector2 drawPosition = new Vector2(xPos, yPos) * TextureSize;
                Rectangle blitRect = new Rectangle((int)drawPosition.X, (int)drawPosition.Y, (int)(TextureSize.X * scale), (int)(TextureSize.Y * scale));
                spriteBatch.Draw(texture, blitRect, Color.White);
            }
        }
    }
}
