﻿using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;

namespace GGJ_Engine
{
    // An generic button class
    public class InterfaceElement
    {
        // Connect an function to the delegate
        public delegate void ButtonCallback(InterfaceElement sender);
        public event ButtonCallback Triggered;

        public enum InterfaceElementState
        {
            Inactive = 0,
            Hover,
            Pressed,
            Disabled
        };

        public InterfaceElementState interfaceElementState = InterfaceElementState.Inactive;

        public Texture2D inactiveTexture;
        public Texture2D hoverTexture;
        public Texture2D pressedTexture;
        public Texture2D disabledTexture;

        public Rectangle Rectangle { get; set; }

        public ContentManager content;

        public InterfaceElement(ContentManager content)
        {
            this.content = content;
            this.Rectangle = new Rectangle(0, 0, 128, 128);
        }

        public Texture2D getCurrentTexture()
        {
            switch (interfaceElementState)
            {
                case InterfaceElementState.Inactive:
                    return inactiveTexture;
                case InterfaceElementState.Hover:
                    return hoverTexture;
                case InterfaceElementState.Pressed:
                    return pressedTexture;
                case InterfaceElementState.Disabled:
                    return disabledTexture;
                default:
                    return inactiveTexture;
            }
        }

        public void setPosition(int x, int y)
        {
            this.Rectangle = new Rectangle(x, y, this.Rectangle.Width, this.Rectangle.Height);
        }

        virtual public void LoadContent()
        {
            // Overload this method for using individual content
        }

        public void performClick()
        {
            // Call connected function
            this.Triggered(this);
        }
    }
}
